#
# spec file for package girara
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libgirara-gtk3
%define so_ver  3
Name:           girara
Version:        0.2.8
Release:        lp151.2.4
Summary:        Graphical user interface library
License:        Zlib
Group:          Development/Libraries/C and C++
Url:            http://pwmt.org/projects/girara
Source0:        http://pwmt.org/projects/girara/download/%{name}-%{version}.tar.gz
BuildRequires:  gettext
BuildRequires:  libxml2-tools
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.50
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libnotify)

%description
girara is a library that implements a user interface that focuses on
simplicity and minimalism. Currently based on GTK+,
it provides an interface that focuses on three main
components: A so-called view widget that represents the actual
application (e.g. a website (browser), an image (image viewer) or the
document (document viewer)), an input bar that is used to execute
commands of the application and the status bar which provides the user
with current information. girara was designed to replace and enhance
the user interface that is used by zathura and jumanji and other
features that those applications share.

%package -n %{libname}-%{so_ver}
Summary:        A graphical user interface library
Group:          System/Libraries

%description -n %{libname}-%{so_ver}
girara is a library that implements a user interface that focuses on
simplicity and minimalism. Currently based on GTK+,
it provides an interface that focuses on three main
components: A so-called view widget that represents the actual
application (e.g. a website (browser), an image (image viewer) or the
document (document viewer)), an input bar that is used to execute
commands of the application and the status bar which provides the user
with current information. girara was designed to replace and enhance
the user interface that is used by zathura and jumanji and other
features that those applications share.

%package devel
Summary:        Header files for the girara library
Group:          Development/Libraries/C and C++
Requires:       %{libname}-%{so_ver} = %{version}-%{release}

%description devel
Header files for the girara user interface library.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
make %{?_smp_mflags} COLOR=0 VERBOSE=1

%install
make install \
	DESTDIR=%{buildroot} \
	LIBDIR=%{_libdir} \
	COLOR=0 \
    VERBOSE=1

%find_lang %{libname}-%{so_ver}
find %{buildroot} -name '*.*a' -delete -print

%post -n %{libname}-%{so_ver} -p /sbin/ldconfig
%postun	-n %{libname}-%{so_ver} -p /sbin/ldconfig

%files -n %{libname}-%{so_ver} -f %{libname}-%{so_ver}.lang
%doc LICENSE README
%{_libdir}/libgirara-gtk3.so.*

%files devel
%{_libdir}/libgirara-gtk3.so
%{_includedir}/girara
%{_libdir}/pkgconfig/girara-gtk3.pc

%changelog
* Fri Jan 26 2018 mimi.vx@gmail.com
- update to 0.2.7
- respect optflags
- spec-cleaned
  * Adopt CSS to newer GTK+ 3 releases
  * Remove obsolete features
  * Update translations
  * Various fixes and improvments
* Sun Feb  5 2017 mimi.vx@gmail.com
- update to 0.2.7
- drop girara-font-handling.patch
  * Various fixes and improvments
  * Updated font handling
* Mon Oct 17 2016 jengelh@inai.de
- Update rpm group; trim description
* Thu Oct 13 2016 mimi.vx@gmail.com
- add girara-font-handling.patch -- fix for gtk-3.21+ compaktibility
* Thu Jun  2 2016 mimi.vx@gmail.com
- update to 0.2.6
  * GTK+ 3.20 compatibility
  * Update translations
* Tue Feb 23 2016 mimi.vx@gmail.com
-  update to 0.2.5
  * Make scrollbar styleable
  * Build with C11 standard
  * Enable LFS everywhere
  * Home key mapping
  * Bind ctrl-[,j,]
  * Update translations
* Mon May 11 2015 mimi.vx@gmail.com
- edhance spec to better work with so_version
* Sun May 10 2015 mimi.vx@gmail.com
- update to 0.2.4
  * Make xembed support optional
  * Use GDK_WINDOWING_X11
  * Command to dump settings to JSON file
  * Make undershoot transparent
  * Update build system
  * Update documentation
  * Update translations
* Tue Oct 28 2014 mimi.vx@gmail.com
- change licence to Zlib
* Mon Oct 27 2014 mimi.vx@gmail.com
- move to group System/Libraries
* Fri Oct 24 2014 mimi.vx@gmail.com
- merge old changelog
* Thu Oct 23 2014 mimi.vx@gmail.com
- remove unneed deps
* Thu Oct 23 2014 mimi.vx@gmail.com
- rename giara-devel
* Thu Oct 23 2014 mimi.vx@gmail.com
- remove check
- add SONAME
* Thu Oct 23 2014 mimi.vx@gmail.com
- add ncurses-utils to deps
* Thu Oct 23 2014 mimi.vx@gmail.com
- move to pkg-config
- add check
* Thu Oct 23 2014 mimi.vx@gmail.com
- update to 0.23 upstream version
* Sat May 12 2012 seiler@b1-systems.de
- removed outcommented lines
- changed lang package name to follow SUSE guidelines
- added rpm optflags...RPM guidelines
* Thu Apr 26 2012 seiler@b1-systems.de
- enhanced Summary of libgirara to increase the chance to get this thing upstream
* Wed Apr 25 2012 seiler@b1-systems.de
- changed wrong dependency because of this error
  unresolvable: nothing provides girara = 0.1.2 needed by girara-devel
* Wed Apr 25 2012 seiler@b1-systems.de
- initial commit
